Readme
======

``latest`` is a LaTeX-oriented template engine.

Basic Usage
-----------

Run `latest` script from the command line

.. code-block:: bash

    latest template data


where

    * `template` is the path to a template file and
    * `data` is the path to a yaml formatted data file.


.. image:: https://travis-ci.org/bluephlavio/latest.svg?branch=master
   :target: https://travis-ci.org/bluephlavio/latest
